lxm3.xm\_cluster.Local
======================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: Local

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Local.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Local.requirements
      ~Local.singularity_options
   
   